@@ -11,10 +11,7 @@ pub struct FileStyle {
   file_time_color: String,
   file_size_color: String,
   file_owner_color: String,
-  file_perms_color: String,
   file_extension_color: String,
-  dir_name_style: String,
-  file_name_style: String,
   file_size_style: String,
   file_owner_style: String,
   file_perms_style: String,
@@ -43,10 +40,7 @@ impl FileStyle {
     file_time_col: String,
     file_size_col: String,
     file_owner_col: String,
-    file_perms_col: String,
     file_ext_col: String,
-    dir_name_sty: String,
-    file_name_sty: String,
     file_size_sty: String,
     file_owner_sty: String,
     file_perms_sty: String,
@@ -72,10 +66,7 @@ impl FileStyle {
         file_time_color: file_time_col.to_uppercase(),
         file_size_color: file_size_col.to_uppercase(),
         file_owner_color: file_owner_col.to_uppercase(),
-        file_perms_color: file_perms_col.to_uppercase(),
         file_extension_color: file_ext_col.to_uppercase(),
-        dir_name_style: dir_name_sty.to_uppercase(),
-        file_name_style: file_name_sty.to_uppercase(),
         file_size_style: file_size_sty.to_uppercase(),
         file_owner_style: file_owner_sty.to_uppercase(),
         file_perms_style: file_perms_sty.to_uppercase(),
