@@ -1,14 +1,13 @@
 use std::{fs};
 use std::path::{PathBuf};
 use std::error::Error;
-use crate::protocols::{File, EnvManager};
+use crate::protocols::{File, ConfigManager};
 use crate::protocols::file::{FileStyle, DisplayPositions};
 
 #[derive(Clone)]
 pub struct TreeGenerator {
     root_dir: PathBuf,
     tree: Vec<String>,
-    pipe: String,
     elbow: String, 
     tee: String,
     pipe_prefix: String,
@@ -25,7 +24,7 @@ pub struct TreeGenerator {
 }
 
 impl TreeGenerator {
-    pub fn init(root_dir: PathBuf, env_manager: EnvManager) -> Self {
+    pub fn init(root_dir: PathBuf, env_manager: ConfigManager) -> Self {
         let positions: DisplayPositions = DisplayPositions::new(env_manager.file_size_position, env_manager.file_owner_position, env_manager.file_perms_position, env_manager.file_time_position, env_manager.file_extension_position);
         let file_style: FileStyle = FileStyle::new(
             positions,
@@ -34,10 +33,7 @@ impl TreeGenerator {
             env_manager.file_time_color,
             env_manager.file_size_color,
             env_manager.file_owner_color,
-            env_manager.file_perms_color,
             env_manager.file_extension_color,
-            env_manager.dir_name_style,
-            env_manager.file_name_style,
             env_manager.file_size_style,
             env_manager.file_owner_style,
             env_manager.file_perms_style,
@@ -60,7 +56,6 @@ impl TreeGenerator {
 
         Self {
             tree: Vec::new(),
-            pipe:  env_manager.pipe,
             elbow:  env_manager.elbow,
             tee:  env_manager.tee,
             pipe_prefix:  env_manager.pipe_prefix,
